@@ -578,7 +578,7 @@ class Pvwatts(Solar, ABC):
         Returns
         -------
         output : np.ndarray
-            1D array of hourly AC inverter power generation in kW.
+            1D array of AC inverter power generation in kW.
             Datatype is float32 and array length is 8760*time_interval.
         """
         return self.ac()
@@ -589,22 +589,39 @@ class Pvwatts(Solar, ABC):
         Returns
         -------
         output : np.ndarray
-            1D array of hourly AC inverter power generation in kW.
+            1D array of AC inverter power generation in kW.
             Datatype is float32 and array length is 8760*time_interval.
         """
         return np.array(self['ac'], dtype=np.float32) / 1000
 
     def dc(self):
-        """Get DC array power generation profile (orig timezone) in kW.
+        """
+        Get DC array power generation profile (orig timezone) in kW.
 
         Returns
         -------
         output : np.ndarray
-            1D array of hourly DC array power generation in kW.
+            1D array of DC array power generation in kW.
             Datatype is float32 and array length is 8760*time_interval.
         """
         return np.array(self['dc'], dtype=np.float32) / 1000
 
+    def clipped_power(self):
+        """
+        Get the clipped DC power generated behind the inverter
+        (orig timezone) in kW.
+
+        Returns
+        -------
+        clipped : np.ndarray
+            1D array of clipped DC power in kW.
+            Datatype is float32 and array length is 8760*time_interval.
+        """
+        ac = self.ac()
+        dc = self.dc()
+
+        return np.where(ac < ac.max(), 0, dc - ac)
+
     @property
     def default(self):
         """Get the executed default pysam PVWATTS object."""
@@ -627,6 +644,7 @@ class Pvwatts(Solar, ABC):
                              'gen_profile': self.gen_profile,
                              'ac': self.ac,
                              'dc': self.dc,
+                             'clipped_power': self.clipped_power
                              }
 
         super().collect_outputs(output_lookup=output_lookup)
