@@ -97,6 +97,9 @@ class Gen(BaseGen):
                  'dc': {'scale_factor': 1, 'units': 'kW',
                         'dtype': 'float32', 'chunks': (None, 100),
                         'type': 'array'},
+                 'clipped_power': {'scale_factor': 1, 'units': 'kW',
+                                   'dtype': 'float32', 'chunks': (None, 100),
+                                   'type': 'array'},
                  'poa': {'scale_factor': 1, 'units': 'W/m2',
                          'dtype': 'float32', 'chunks': (None, 100),
                          'type': 'array'},
